==> ec2-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/InterfaceVpcEndpoint.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A interface VPC endpoint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:19:47.006Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.InterfaceVpcEndpoint")
public class InterfaceVpcEndpoint extends software.amazon.awscdk.services.ec2.VpcEndpoint implements software.amazon.awscdk.services.ec2.IInterfaceVpcEndpoint {
    protected InterfaceVpcEndpoint(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public InterfaceVpcEndpoint(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.InterfaceVpcEndpointProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Imports an existing interface VPC endpoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IInterfaceVpcEndpoint fromInterfaceVpcEndpointAttributes(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.InterfaceVpcEndpointAttributes attrs) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InterfaceVpcEndpoint.class, "fromInterfaceVpcEndpointAttributes", software.amazon.awscdk.services.ec2.IInterfaceVpcEndpoint.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(attrs, "attrs is required") });
    }

    /**
     * Access to network connections.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.ec2.Connections getConnections() {
        return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
    }

    /**
     * The identifier of the security group associated with this interface VPC endpoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSecurityGroupId() {
        return this.jsiiGet("securityGroupId", java.lang.String.class);
    }

    /**
     * The date and time the interface VPC endpoint was created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getVpcEndpointCreationTimestamp() {
        return this.jsiiGet("vpcEndpointCreationTimestamp", java.lang.String.class);
    }

    /**
     * The DNS entries for the interface VPC endpoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getVpcEndpointDnsEntries() {
        return this.jsiiGet("vpcEndpointDnsEntries", java.util.List.class);
    }

    /**
     * The interface VPC endpoint identifier.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getVpcEndpointId() {
        return this.jsiiGet("vpcEndpointId", java.lang.String.class);
    }

    /**
     * One or more network interfaces for the interface VPC endpoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getVpcEndpointNetworkInterfaceIds() {
        return this.jsiiGet("vpcEndpointNetworkInterfaceIds", java.util.List.class);
    }
}

==> ec2-1.5.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/InterfaceVpcEndpoint.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A interface VPC endpoint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.15.1 (build ceff2ca)", date = "2019-08-21T10:50:03.220Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.InterfaceVpcEndpoint")
public class InterfaceVpcEndpoint extends software.amazon.awscdk.services.ec2.VpcEndpoint implements software.amazon.awscdk.services.ec2.IInterfaceVpcEndpoint {

    protected InterfaceVpcEndpoint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InterfaceVpcEndpoint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public InterfaceVpcEndpoint(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.InterfaceVpcEndpointProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     * Imports an existing interface VPC endpoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IInterfaceVpcEndpoint fromInterfaceVpcEndpointAttributes(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.InterfaceVpcEndpointAttributes attrs) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.InterfaceVpcEndpoint.class, "fromInterfaceVpcEndpointAttributes", software.amazon.awscdk.services.ec2.IInterfaceVpcEndpoint.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(attrs, "attrs is required") });
    }

    /**
     * Access to network connections.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.ec2.Connections getConnections() {
        return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
    }

    /**
     * The identifier of the security group associated with this interface VPC endpoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSecurityGroupId() {
        return this.jsiiGet("securityGroupId", java.lang.String.class);
    }

    /**
     * The date and time the interface VPC endpoint was created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getVpcEndpointCreationTimestamp() {
        return this.jsiiGet("vpcEndpointCreationTimestamp", java.lang.String.class);
    }

    /**
     * The DNS entries for the interface VPC endpoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getVpcEndpointDnsEntries() {
        return this.jsiiGet("vpcEndpointDnsEntries", java.util.List.class);
    }

    /**
     * The interface VPC endpoint identifier.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getVpcEndpointId() {
        return this.jsiiGet("vpcEndpointId", java.lang.String.class);
    }

    /**
     * One or more network interfaces for the interface VPC endpoint.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getVpcEndpointNetworkInterfaceIds() {
        return this.jsiiGet("vpcEndpointNetworkInterfaceIds", java.util.List.class);
    }
}
